%global codename fuerte
%global shortname geometry

Name:		ros-%{codename}-geometry
Version:	1.8.0
Release:	2%{?dist}
Summary:	Basic ROS geometric and math libraries
License:	BSD and LGPLv2+ and zlib
URL:		http://ros.org/wiki/geometry
Source0:	https://code.ros.org/svn/release/download/stacks/geometry/geometry-%{version}/geometry-%{version}.tar.bz2
# Fix gcc 4.7 issues
Patch0:		ros-geometry-gcc47.patch
BuildRequires:	ros-%{codename}-ros-devel, ros-%{codename}-ros-comm-devel
BuildRequires:	ros-%{codename}-bullet-devel, ros-%{codename}-common-msgs-devel
BuildRequires:	ros-%{codename}-orocos-kinematics-dynamics-devel
BuildRequires:	cmake, python-yaml, eigen3-devel, numpy, graphviz
BuildRequires:	chrpath
Requires:	numpy, graphviz
Provides:	ros-%{shortname} = %{version}-%{release}

%description
The basic geometric and math libraries used in ROS.

%package devel
Summary:	Development files for ROS geometry
Requires:	ros-%{codename}-ros-devel, ros-%{codename}-ros-comm-devel
Requires:	ros-%{codename}-bullet-devel, ros-%{codename}-common-msgs-devel
Requires:	ros-%{codename}-orocos-kinematics-dynamics-devel
Requires:	eigen3-devel
Requires:	%{name} = %{version}-%{release}
Provides:	ros-%{shortname}-devel = %{version}-%{release}

%description devel
Development files for ROS geometry.

%prep
%setup -q -c
# We have to do this so the cmake gunk can find itself. So idiotic.
mv %{shortname}-%{version} %{shortname}
# We need to make this directory so it can install its own files on top of itself.
# This is a really poorly designed architecture.
mkdir %{shortname}/tf/bin
%patch0 -p1 -b .gcc47

%build
cd %{shortname}
source /etc/catkin/profile.d/10.ros.all
export ROS_PACKAGE_PATH="%{_builddir}/%{name}-%{version}:$ROS_PACKAGE_PATH"
for i in tf angles eigen_conversions tf_conversions; do
  pushd $i
  mkdir build
  cd build
  %cmake -DSETUPTOOLS_DEB_LAYOUT=OFF ..
  make %{?_smp_mflags}
  popd
done

%install
cd %{shortname}
mkdir -p %{buildroot}%{_datadir}/ros-stacks/%{shortname}/
cp -a stack.xml %{buildroot}%{_datadir}/ros-stacks/%{shortname}/

#angles
pushd angles
mkdir -p %{buildroot}%{_datadir}/ros-stacks/%{shortname}/angles
cp -a include *.dox *.xml %{buildroot}%{_datadir}/ros-stacks/%{shortname}/angles/
popd

#eigen_conversions
pushd eigen_conversions
mkdir -p %{buildroot}%{_datadir}/ros-stacks/%{shortname}/eigen_conversions
cp -a include *.dox *.xml %{buildroot}%{_datadir}/ros-stacks/%{shortname}/eigen_conversions/
mkdir -p %{buildroot}%{_libdir}
mkdir -p %{buildroot}%{_datadir}/ros-stacks/%{shortname}/eigen_conversions/lib
cp lib/libeigen_conversions.so %{buildroot}%{_libdir}
ln -s %{_libdir}/libeigen_conversions.so %{buildroot}%{_datadir}/ros-stacks/%{shortname}/eigen_conversions/lib/libeigen_conversions.so
popd

#tf
pushd tf
mkdir -p %{buildroot}%{_datadir}/ros-stacks/%{shortname}/tf/bin
mkdir -p %{buildroot}%{_bindir}
for i in btTest change_notifier empty_listener static_transform_publisher testBroadcaster tf_echo tf_monitor; do
  cp -a bin/$i %{buildroot}%{_bindir}/ros-$i
  ln -s %{_bindir}/ros-$i %{buildroot}%{_datadir}/ros-stacks/%{shortname}/tf/bin/$i
done
cp -a conf.py doc include *.rst *.dox *.xml msg msg_gen remap_tf.launch scripts srv srv_gen %{buildroot}%{_datadir}/ros-stacks/%{shortname}/tf/
mkdir -p %{buildroot}%{_datadir}/ros-stacks/%{shortname}/tf/lib
mkdir -p %{buildroot}%{python_sitearch}
cp -a lib/_tf.so %{buildroot}%{python_sitearch}
ln -s %{python_sitearch}/_tf.so %{buildroot}%{_datadir}/ros-stacks/%{shortname}/tf/lib
cp -a lib/libtf.so %{buildroot}%{_libdir}
ln -s %{_libdir}/libtf.so %{buildroot}%{_datadir}/ros-stacks/%{shortname}/tf/lib/libtf.so
mkdir -p %{buildroot}%{_datadir}/ros-stacks/%{shortname}/tf/src
cp -a src/tf %{buildroot}%{python_sitearch}/
ln -s %{python_sitearch}/tf %{buildroot}%{_datadir}/ros-stacks/%{shortname}/tf/src/tf
popd

#tf_conversions
pushd tf_conversions
mkdir -p %{buildroot}%{_datadir}/ros-stacks/%{shortname}/tf_conversions
cp -a conf.py include *.rst *.yaml *.xml %{buildroot}%{_datadir}/ros-stacks/%{shortname}/tf_conversions/
mkdir -p %{buildroot}%{_datadir}/ros-stacks/%{shortname}/tf_conversions/src
cp -a src/tf_conversions %{buildroot}%{python_sitearch}/
ln -s %{python_sitearch}/tf_conversions %{buildroot}%{_datadir}/ros-stacks/%{shortname}/tf_conversions/src/tf_conversions
mkdir -p  %{buildroot}%{_datadir}/ros-stacks/%{shortname}/tf_conversions/lib
cp -a lib/libtf_conversions.so %{buildroot}%{_libdir}
ln -s %{_libdir}/libtf_conversions.so %{buildroot}%{_datadir}/ros-stacks/%{shortname}/tf_conversions/lib/libtf_conversions.so
popd

chrpath -d %{buildroot}%{_bindir}/* 
chrpath -d %{buildroot}%{_libdir}/*.so
chrpath -d %{buildroot}%{python_sitearch}/*.so

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%{_bindir}/ros-btTest
%{_bindir}/ros-change_notifier
%{_bindir}/ros-empty_listener
%{_bindir}/ros-static_transform_publisher
%{_bindir}/ros-testBroadcaster
%{_bindir}/ros-tf_echo
%{_bindir}/ros-tf_monitor
%{_datadir}/ros-stacks/%{shortname}/
%exclude %{_datadir}/ros-stacks/%{shortname}/angles/include/
%exclude %{_datadir}/ros-stacks/%{shortname}/eigen_conversions/include/
%exclude %{_datadir}/ros-stacks/%{shortname}/tf/include/
%exclude %{_datadir}/ros-stacks/%{shortname}/tf_conversions/include/
%{_libdir}/libeigen_conversions.so
%{_libdir}/libtf.so
%{_libdir}/libtf_conversions.so
%{python_sitearch}/_tf.so
%{python_sitearch}/tf/
%{python_sitearch}/tf_conversions/

%files devel
%{_datadir}/ros-stacks/%{shortname}/angles/include/
%{_datadir}/ros-stacks/%{shortname}/eigen_conversions/include/
%{_datadir}/ros-stacks/%{shortname}/tf/include/
%{_datadir}/ros-stacks/%{shortname}/tf_conversions/include/

%changelog
* Fri Jun  1 2012 Tom Callaway <spot@fedoraproject.org> - 1.8.0-2
- fix gcc 4.7 issues

* Wed May 23 2012 Tom Callaway <spot@fedoraproject.org> - 1.8.0-1
- initial package
